@@ -44,19 +44,22 @@ const (
 )
 
 var (
-	version    = ""
-	buildinfos = ""
-	AppVersion = "StayRTR " + version + " " + buildinfos
+	AppVersion = "StayRTR " + rtr.APP_VERSION
 
 	MetricsAddr = flag.String("metrics.addr", ":9847", "Metrics address")
 	MetricsPath = flag.String("metrics.path", "/metrics", "Metrics path")
 
 	ExportPath = flag.String("export.path", "/rpki.json", "Export path")
 
-	RTRVersion = flag.Int("protocol", 2, "RTR protocol version. Version 2 is draft-ietf-sidrops-8210bis-10")
+	RTRVersion = flag.Int("protocol", 1, "RTR protocol version. Default is version 1 (RFC 8210)")
 	RefreshRTR = flag.Int("rtr.refresh", 3600, "Refresh interval")
 	RetryRTR   = flag.Int("rtr.retry", 600, "Retry interval")
 	ExpireRTR  = flag.Int("rtr.expire", 7200, "Expire interval")
+	SendNotifs = flag.Bool("notifications", true, "Send notifications to clients (disable with -notifications=false)")
+	EnforceVersion  = flag.Bool("enforce.version", false, "Disable version negotiation")
+	DisableBGPSec	= flag.Bool("disable.bgpsec", false, "Disable sending out BGPSEC Router Keys")
+	EnableNODELAY	= flag.Bool("enable.nodelay", false, "Force enable TCP NODELAY (Likely increases CPU)")
+
 
 	Bind = flag.String("bind", ":8282", "Bind address")
 
@@ -85,7 +88,6 @@ var (
 	Mime            = flag.String("mime", "application/json", "Accept setting format (some servers may prefer text/json)")
 	RefreshInterval = flag.Int("refresh", 600, "Refresh interval in seconds")
 	MaxConn         = flag.Int("maxconn", 0, "Max simultaneous connections (0 to disable limit)")
-	SendNotifs      = flag.Bool("notifications", true, "Send notifications to clients (disable with -notifications=false)")
 
 	Slurm        = flag.String("slurm", "", "Slurm configuration file (filters and assertions)")
 	SlurmRefresh = flag.Bool("slurm.refresh", true, "Refresh along the cache (disable with -slurm.refresh=false)")
@@ -153,7 +155,6 @@ var (
 	protoverToLib = map[int]uint8{
 		0: rtr.PROTOCOL_VERSION_0,
 		1: rtr.PROTOCOL_VERSION_1,
-		2: rtr.PROTOCOL_VERSION_2,
 	}
 )
 
@@ -204,10 +205,9 @@ func isValidPrefixLength(prefix netip.Prefix, maxLength uint8) bool {
 // 1 - The prefix is a valid prefix
 // 2 - The ASN is a valid ASN
 // 3 - The MaxLength is valid
-// Will return a deduped slice, as well as total VRPs, IPv4 VRPs, IPv6 VRPs, BGPsec Keys and ASPA records
+// Will return a deduped slice, as well as total VRPs, IPv4 VRPs, IPv6 VRPs and BGPsec Keys
 func processData(vrplistjson []prefixfile.VRPJson,
-	brklistjson []prefixfile.BgpSecKeyJson,
-	aspajson []prefixfile.VAPJson) /*Export*/ ([]rtr.VRP, []rtr.BgpsecKey, []rtr.VAP, int, int) {
+	brklistjson []prefixfile.BgpSecKeyJson) /*Export*/ ([]rtr.VRP, []rtr.BgpsecKey, int, int) {
 	filterDuplicates := make(map[string]struct{})
 
 	// It may be tempting to change this to a simple time.Since() but that will
@@ -218,7 +218,6 @@ func processData(vrplistjson []prefixfile.VRPJson,
 
 	var vrplist []rtr.VRP
 	var brklist = make([]rtr.BgpsecKey, 0)
-	var aspalist = make([]rtr.VAP, 0)
 	var countv4 int
 	var countv6 int
 
@@ -319,26 +318,7 @@ func processData(vrplistjson []prefixfile.VRPJson,
 		})
 	}
 
-	for _, v := range aspajson {
-		if v.Expires != nil {
-			if NowUnix > *v.Expires {
-				continue
-			}
-		}
-
-		// Ensure that these are sorted, otherwise they
-		// don't hash right.
-		sort.Slice(v.Providers, func(i, j int) bool {
-			return v.Providers[i] < v.Providers[j]
-		})
-
-		aspalist = append(aspalist, rtr.VAP{
-			CustomerASN: v.CustomerAsid,
-			Providers:   v.Providers,
-		})
-	}
-
-	return vrplist, brklist, aspalist, countv4, countv6
+	return vrplist, brklist, countv4, countv6
 }
 
 type IdenticalFile struct {
@@ -353,8 +333,6 @@ var errRPKIJsonFileTooOld = errors.New("RPKI JSON file is older than 24 hours")
 
 // Update the state based on the current slurm file and data.
 func (s *state) updateFromNewState() error {
-	sessid := s.server.GetSessionId()
-
 	vrpsjson := s.lastdata.ROA
 	if vrpsjson == nil {
 		return nil
@@ -363,10 +341,6 @@ func (s *state) updateFromNewState() error {
 	if bgpsecjson == nil {
 		bgpsecjson = make([]prefixfile.BgpSecKeyJson, 0)
 	}
-	aspajson := s.lastdata.ASPA
-	if aspajson == nil {
-		aspajson = make([]prefixfile.VAPJson, 0)
-	}
 
 	buildtime, err := time.Parse(time.RFC3339, s.lastdata.Metadata.Buildtime)
 	if s.lastdata.Metadata.GeneratedUnix != nil {
@@ -384,20 +358,18 @@ func (s *state) updateFromNewState() error {
 	}
 
 	if s.slurm != nil {
-		vrpsjson, aspajson, bgpsecjson = s.slurm.FilterAssert(vrpsjson, aspajson, bgpsecjson, log.StandardLogger())
+		vrpsjson, bgpsecjson = s.slurm.FilterAssert(vrpsjson, bgpsecjson, log.StandardLogger())
 	}
 
-	vrps, brks, vaps, countv4, countv6 := processData(vrpsjson, bgpsecjson, aspajson)
-	count := len(vrps) + len(brks) + len(vaps)
+	vrps, brks, countv4, countv6 := processData(vrpsjson, bgpsecjson)
+	count := len(vrps) + len(brks)
 
-	log.Infof("New update (%v uniques, %v total prefixes, %v vaps, %v router keys).", len(vrps), count, len(vaps), len(brks))
-	return s.applyUpdateFromNewState(vrps, brks, vaps, sessid, vrpsjson, bgpsecjson, aspajson, countv4, countv6)
+	log.Infof("New update (%v uniques, %v total prefixes, %v router keys).", len(vrps), count, len(brks))
+	return s.applyUpdateFromNewState(vrps, brks, vrpsjson, bgpsecjson, countv4, countv6)
 }
 
 // Update the state based on the currently loaded files
 func (s *state) reloadFromCurrentState() error {
-	sessid := s.server.GetSessionId()
-
 	vrpsjson := s.lastdata.ROA
 	if vrpsjson == nil {
 		return nil
@@ -406,10 +378,6 @@ func (s *state) reloadFromCurrentState() error {
 	if bgpsecjson == nil {
 		bgpsecjson = make([]prefixfile.BgpSecKeyJson, 0)
 	}
-	aspajson := s.lastdata.ASPA
-	if aspajson == nil {
-		aspajson = make([]prefixfile.VAPJson, 0)
-	}
 
 	buildtime, err := time.Parse(time.RFC3339, s.lastdata.Metadata.Buildtime)
 	if s.lastdata.Metadata.GeneratedUnix != nil {
@@ -427,39 +395,35 @@ func (s *state) reloadFromCurrentState() error {
 	}
 
 	if s.slurm != nil {
-		vrpsjson, aspajson, bgpsecjson = s.slurm.FilterAssert(vrpsjson, aspajson, bgpsecjson, log.StandardLogger())
+		vrpsjson, bgpsecjson = s.slurm.FilterAssert(vrpsjson, bgpsecjson, log.StandardLogger())
 	}
 
-	vrps, brks, vaps, countv4, countv6 := processData(vrpsjson, bgpsecjson, aspajson)
-	count := len(vrps) + len(brks) + len(vaps)
+	vrps, brks, countv4, countv6 := processData(vrpsjson, bgpsecjson)
+	count := len(vrps) + len(brks)
 	if s.server.CountSDs() != count {
 		log.Infof("New update to old state (%v uniques, %v total prefixes). (old %v - new %v)", len(vrps), count, s.server.CountSDs(), count)
-		return s.applyUpdateFromNewState(vrps, brks, vaps, sessid, vrpsjson, bgpsecjson, aspajson, countv4, countv6)
+		return s.applyUpdateFromNewState(vrps, brks, vrpsjson, bgpsecjson, countv4, countv6)
 	}
 	return nil
 }
 
-func (s *state) applyUpdateFromNewState(vrps []rtr.VRP, brks []rtr.BgpsecKey, vaps []rtr.VAP,
-	sessid uint16,
-	vrpsjson []prefixfile.VRPJson, brksjson []prefixfile.BgpSecKeyJson, aspajson []prefixfile.VAPJson,
+func (s *state) applyUpdateFromNewState(vrps []rtr.VRP, brks []rtr.BgpsecKey,
+	vrpsjson []prefixfile.VRPJson, brksjson []prefixfile.BgpSecKeyJson,
 	countv4 int, countv6 int) error {
 
-	SDs := make([]rtr.SendableData, 0, len(vrps)+len(brks)+len(vaps))
+	SDs := make([]rtr.SendableData, 0, len(vrps) + len(brks))
 	for _, v := range vrps {
 		SDs = append(SDs, v.Copy())
 	}
 	for _, v := range brks {
 		SDs = append(SDs, v.Copy())
 	}
-	for _, v := range vaps {
-		SDs = append(SDs, v.Copy())
-	}
 	if !s.server.AddData(SDs) {
 		log.Info("No difference to current cache")
 		return nil
 	}
 
-	serial, _ := s.server.GetCurrentSerial(sessid)
+	serial, _ := s.server.GetCurrentSerial()
 	log.Infof("Update added, new serial %v", serial)
 	if s.sendNotifs {
 		log.Debugf("Sending notifications to clients")
@@ -475,9 +439,7 @@ func (s *state) applyUpdateFromNewState(vrps []rtr.VRP, brks []rtr.BgpsecKey, va
 		},
 		ROA:        vrpsjson,
 		BgpSecKeys: brksjson,
-		ASPA:       aspajson,
 	}
-
 	s.lockJson.Unlock()
 
 	if s.metricsEvent != nil {
@@ -490,7 +452,7 @@ func (s *state) applyUpdateFromNewState(vrps []rtr.VRP, brks []rtr.BgpsecKey, va
 				countv6_dup++
 			}
 		}
-		s.metricsEvent.UpdateMetrics(countv4, countv6, countv4_dup, countv6_dup, s.lastchange, s.lastts, *CacheBin, len(brks), len(vaps))
+		s.metricsEvent.UpdateMetrics(countv4, countv6, countv4_dup, countv6_dup, s.lastchange, s.lastts, *CacheBin, len(brks))
 	}
 
 	return nil
@@ -710,8 +672,7 @@ func (m *metricsEvent) HandlePDU(c *rtr.Client, pdu rtr.PDU) {
 				"_", -1))).Inc()
 }
 
-func (m *metricsEvent) UpdateMetrics(numIPv4 int, numIPv6 int, numIPv4filtered int, numIPv6filtered int, changed time.Time, refreshed time.Time, file string, brkCount int, aspaCount int) {
-	NumberOfObjects.WithLabelValues("vaps").Set(float64(aspaCount))
+func (m *metricsEvent) UpdateMetrics(numIPv4 int, numIPv6 int, numIPv4filtered int, numIPv6filtered int, changed time.Time, refreshed time.Time, file string, brkCount int) {
 	NumberOfObjects.WithLabelValues("bgpsec_pubkeys").Set(float64(brkCount))
 	NumberOfObjects.WithLabelValues("vrps").Set(float64(numIPv4 + numIPv6))
 	NumberOfObjects.WithLabelValues("effective_vrps").Set(float64(numIPv4filtered + numIPv6filtered))
@@ -763,6 +724,10 @@ func run() error {
 		RefreshInterval: uint32(*RefreshRTR),
 		RetryInterval:   uint32(*RetryRTR),
 		ExpireInterval:  uint32(*ExpireRTR),
+
+		EnforceVersion:  *EnforceVersion,
+		DisableBGPSec:   *DisableBGPSec,
+		EnableNODELAY:   *EnableNODELAY,
 	}
 
 	var me *metricsEvent
@@ -853,8 +818,9 @@ func run() error {
 
 	if *Bind != "" {
 		go func() {
-			sessid := server.GetSessionId()
+			sessid := server.GetSessionId(protoverToLib[*RTRVersion])
 			log.Infof("StayRTR Server started (sessionID:%d, refresh:%d, retry:%d, expire:%d)", sessid, sc.RefreshInterval, sc.RetryInterval, sc.ExpireInterval)
+			log.Infof("StayRTR Server v%s binding to %s", rtr.APP_VERSION, *Bind)
 			err := server.Start(*Bind)
 			if err != nil {
 				log.Fatal(err)
